import { useEffect, useState } from 'react';
import useSDKFactory from './useSDKFactory';
import { UseCase, RRListenable, SRListenable, } from '@inkerlabs/sdk';
import useAccount from './useAccount';
export default function useNFTsFactory(useCase) {
    return function useNFTs() {
        var sdk = useSDKFactory()();
        var _a = useState(undefined), nfts = _a[0], setNfts = _a[1];
        var _b = useState(undefined), error = _b[0], setError = _b[1];
        var account = useAccount();
        var id;
        var cb = function (err, nfts) {
            setError(err);
            setNfts(nfts);
        };
        var unlisten = function () {
            switch (useCase) {
                case UseCase.RR:
                    var rrSDK = sdk;
                    if (id) {
                        rrSDK.unlisten(id, RRListenable.REVEALABLE);
                    }
                    break;
                case UseCase.SR:
                    var srSDK = sdk;
                    if (id) {
                        srSDK.unlisten(id, SRListenable.NFTS);
                    }
                    break;
                default:
                    throw new Error("Unsupported use case ".concat(useCase));
            }
        };
        useEffect(function () {
            unlisten();
            switch (useCase) {
                case UseCase.RR:
                    var rrSDK = sdk;
                    rrSDK.listen(RRListenable.REVEALABLE, cb);
                    break;
                case UseCase.SR:
                    var srSDK = sdk;
                    srSDK.listen(SRListenable.NFTS, cb);
                    break;
                default:
                    throw new Error("Unsupported use case ".concat(useCase));
            }
        }, [account]);
        // Emulate componentWillUnmount
        useEffect(function () {
            return function () {
                unlisten();
            };
        }, []);
        return [nfts, error];
    };
}
