import { useEffect, useState } from 'react';
import useSDKFactory from './useSDKFactory';
import { UseCase, PassListenable, RRListenable, SRListenable, } from '@inkerlabs/sdk';
import useAccount from './useAccount';
export default function useWhiteListTicketsFactory(useCase) {
    return function useWhiteListTickets() {
        var sdk = useSDKFactory()();
        var account = useAccount();
        var _a = useState(undefined), tickets = _a[0], setTickets = _a[1];
        var _b = useState(undefined), error = _b[0], setError = _b[1];
        var id;
        var cb = function (err, _tickets) {
            setError(err);
            setTickets(_tickets);
        };
        var unlisten = function () {
            switch (useCase) {
                case UseCase.PASS:
                    var passSDK = sdk;
                    if (id) {
                        passSDK.unlisten(id, PassListenable.WHITELIST_TICKETS);
                    }
                    break;
                case UseCase.RR:
                    var rrSDK = sdk;
                    if (id) {
                        rrSDK.unlisten(id, RRListenable.WHITELIST_TICKETS);
                    }
                    break;
                case UseCase.SR:
                    var srSDK = sdk;
                    if (id) {
                        srSDK.unlisten(id, SRListenable.WHITELIST_TICKETS);
                    }
                    break;
                default:
                    throw new Error("Unsupported use case ".concat(useCase));
            }
        };
        useEffect(function () {
            unlisten();
            switch (useCase) {
                case UseCase.PASS:
                    var passSDK = sdk;
                    passSDK.listen(PassListenable.WHITELIST_TICKETS, cb);
                    break;
                case UseCase.RR:
                    var rrSDK = sdk;
                    rrSDK.listen(RRListenable.WHITELIST_TICKETS, cb);
                    break;
                case UseCase.SR:
                    var srSDK = sdk;
                    srSDK.listen(SRListenable.WHITELIST_TICKETS, cb);
                    break;
                default:
                    throw new Error("Unsupported use case ".concat(useCase));
            }
        }, [account]);
        // Emulate componentWillUnmount
        useEffect(function () {
            return function () {
                unlisten();
            };
        }, []);
        return [tickets, error];
    };
}
